@@ -27,4 +27,7 @@ void 	     application_history_write_config 	(void);
 float	     application_display_dpi_get (gboolean const horizontal);
 void 	     application_display_dpi_set (gboolean const horizontal, float const);
 
+gboolean     application_use_auto_complete_get (void);
+void         application_use_auto_complete_set (gboolean use_auto_complete);
+
 #endif /* GNUMERIC_APPLICATION_H */
