@@ -2,18 +2,19 @@
 #define GNUMERIC_CLIPBOARD_H
 
 enum {
-	PASTE_VALUES   = 1 << 0,
-	PASTE_FORMULAS = 1 << 1,
-	PASTE_FORMATS  = 1 << 2,
+	PASTE_VALUES		= 1 << 0, /* At most VALUES or FORMATS can */
+	PASTE_FORMULAS		= 1 << 1, /*  be applied */
+	PASTE_FORMATS		= 1 << 2,
 
 	/* Operations that can be performed at paste time on a cell */
-	PASTE_OPER_ADD   = 1 << 3,
-	PASTE_OPER_SUB   = 1 << 4,
-	PASTE_OPER_MULT  = 1 << 5,
-	PASTE_OPER_DIV   = 1 << 6,
+	PASTE_OPER_ADD		= 1 << 3,
+	PASTE_OPER_SUB		= 1 << 4,
+	PASTE_OPER_MULT		= 1 << 5,
+	PASTE_OPER_DIV		= 1 << 6,
 
 	/* Whether the paste transposes or not */
-	PASTE_TRANSPOSE  = 1 << 7
+	PASTE_TRANSPOSE		= 1 << 7,
+	PASTE_EXPR_RELOCATE	= 1 << 8
 };
 
 #define PASTE_ALL_TYPES (PASTE_FORMULAS | PASTE_VALUES | PASTE_FORMATS)
@@ -39,24 +40,27 @@ typedef struct {
 typedef GList CellCopyList;
 
 struct _CellRegion {
+	int          base_col, base_row;
 	int          cols, rows;
 	CellCopyList *list;
 	GList        *styles;
 };
 
-CellRegion *clipboard_copy_cell_range    (Sheet *sheet,
-					  int start_col, int start_row,
-					  int end_col,   int end_row);
-
-void        clipboard_paste_region       (CommandContext *context, CellRegion *region,
-					  Sheet      *dest_sheet,
-					  int         dest_col,
-					  int         dest_row,
-					  int         paste_flags,
-					  guint32     time32);
-
-void        clipboard_release            (CellRegion *region);
+struct _PasteTarget {
+	Sheet      *sheet;
+	Range	    range;
+	int         paste_flags;
+};
 
+CellRegion *clipboard_copy_range   (Sheet *sheet, Range const *r);
+void        clipboard_release      (CellRegion *region);
+gboolean    clipboard_paste_region (CommandContext *context,
+				    PasteTarget const *pt,
+				    CellRegion *content);
+void 	    clipboard_paste	   (CommandContext *context,
+				    PasteTarget const *pt, guint32 time);
+PasteTarget*paste_target_init      (PasteTarget *pt,
+				    Sheet *sheet, Range const *r, int flags);
 void        x_clipboard_bind_workbook    (Workbook *wb);
 	
 #endif /* GNUMERIC_CLIPBOARD_H */
