@@ -606,14 +606,14 @@ fmt_dialog_init_fmt_list (GtkCList *cl, char const * const *formats,
 static void
 fmt_dialog_enable_widgets (FormatState *state, int page)
 {
-	static FormatWidget contents[12][7] = {
+	static FormatWidget contents[12][8] = {
 		/* General */
 		{ F_GENERAL, F_MAX_WIDGET },
 		/* Number */
 		{ F_DECIMAL_BOX, F_DECIMAL_SPIN, F_SEPARATOR,
 		  F_NEGATIVE_SCROLL, F_NEGATIVE, F_MAX_WIDGET },
 		/* Currency */
-		{ F_DECIMAL_BOX, F_DECIMAL_SPIN, F_SYMBOL_LABEL, F_SYMBOL,
+		{ F_DECIMAL_BOX, F_DECIMAL_SPIN, F_SEPARATOR, F_SYMBOL_LABEL, F_SYMBOL,
 		  F_NEGATIVE_SCROLL, F_NEGATIVE, F_MAX_WIDGET },
 		/* Accounting */
 		{ F_DECIMAL_BOX, F_DECIMAL_SPIN, F_SYMBOL_LABEL, F_SYMBOL, F_MAX_WIDGET },
@@ -721,7 +721,7 @@ cb_format_changed (GtkObject *obj, FormatState *state)
 {
 	GtkToggleButton *button = GTK_TOGGLE_BUTTON (obj);
 	if (gtk_toggle_button_get_active (button))
-		fmt_dialog_enable_widgets ( state,
+		fmt_dialog_enable_widgets (state,
 			GPOINTER_TO_INT (gtk_object_get_data (obj, "index")));
 }
 
@@ -1441,6 +1441,15 @@ draw_pattern_selected (FormatState *state)
 
 /*****************************************************************************/
 
+/*
+ * This is self-evident.
+ * I stared at it for 15 minutes before realizing that it's self-evident,
+ * but it is. - jon_kare
+ *
+ * @points:   x, y coordinates for the endpoints of the line segment.
+ * @states:   A bitmap of states the coordinates are valid for.
+ * @location: Location.
+ */
 #define L 10.	/* Left */
 #define R 140.	/* Right */
 #define T 10.	/* Top */
@@ -1660,9 +1669,9 @@ static void
 draw_border_preview (FormatState *state)
 {
 	static double const corners[12][6] = {
-	    { T-5., T, L, T, L, T-5. },
+	    { L-5., T, L, T, L, T-5. },
 	    { R+5., T, R, T, R, T-5 },
-	    { T-5., B, L, B, L, B+5. },
+	    { L-5., B, L, B, L, B+5. },
 	    { R+5., B, R, B, R, B+5. },
 
 	    { V-5., T-1., V, T-1., V, T-5. },
@@ -1909,7 +1918,7 @@ cb_fmt_dialog_dialog_apply (GtkObject *w, int page, FormatState *state)
 		    state->sheet, state->result, borders);
 
 	mstyle_unref (state->result);
-	sheet_update_controls (state->sheet);
+	sheet_update (state->sheet);
 
 	/* Get a fresh style to accumulate results in */
 	state->result = mstyle_new ();
