@@ -41,8 +41,8 @@ typedef struct {
 	int        asc;
 	GtkWidget *asc_desc;
 	GSList    *group;
-	gboolean cs;
-	gboolean val;
+	gboolean   cs;
+	gboolean   val;
 	GtkWidget *adv_button;
 	Workbook  *wb;
 } OrderBox;
@@ -58,7 +58,7 @@ typedef struct {
 	GtkWidget *dialog;
 	GtkWidget *clause_box;
 	gboolean   header;
-	gboolean   columns;
+	gboolean   top;
 	GList     *colnames_plain;
 	GList     *colnames_header;
 	GList     *rownames_plain;
@@ -214,6 +214,8 @@ order_box_new (GtkWidget * parent, const gchar *frame_text,
 	OrderBox *orderbox;
 	GtkWidget *hbox = gtk_hbox_new (FALSE, 2);
 
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+	
 	orderbox  = g_new (OrderBox, 1);
 	orderbox->parent = parent;
 	orderbox->main_frame = gtk_frame_new (frame_text);
@@ -232,7 +234,7 @@ order_box_new (GtkWidget * parent, const gchar *frame_text,
 
 		orderbox->asc = 1;
 		orderbox->asc_desc = gtk_hbox_new (FALSE, 0);
-
+		
 		item = gtk_radio_button_new_with_label (group, _("Ascending"));
 		gtk_box_pack_start (GTK_BOX (orderbox->asc_desc), item, FALSE, FALSE, 0);
 		group = gtk_radio_button_group (GTK_RADIO_BUTTON (item));
@@ -247,8 +249,14 @@ order_box_new (GtkWidget * parent, const gchar *frame_text,
 	/* Advanced button */
 	orderbox->cs = FALSE;
 	orderbox->val = TRUE;
-	orderbox->adv_button = gtk_button_new_with_label(_("Advanced..."));
-	gtk_box_pack_start (GTK_BOX (hbox), orderbox->adv_button, FALSE, FALSE, 0);
+	
+	{
+		GtkWidget *pm = gnome_stock_new_with_icon (GNOME_STOCK_PIXMAP_PROPERTIES);
+		orderbox->adv_button = gnome_pixmap_button (pm, _("Advanced..."));
+	}
+	
+	gtk_box_pack_start (GTK_BOX (hbox), orderbox->adv_button, 
+			    FALSE, FALSE, 0);
 	gtk_signal_connect (GTK_OBJECT (orderbox->adv_button), "clicked",
 		GTK_SIGNAL_FUNC (dialog_cell_sort_adv),  orderbox);
 
@@ -300,11 +308,12 @@ order_box_destroy (OrderBox *orderbox)
 static gboolean
 dialog_cell_sort_ok (SortFlow *sf)
 {
+	SortData *data;
 	SortClause *array;
 	gint divstart, divend;
 	int lp;
 
-	if (sf->columns) {
+	if (sf->top) {
 		divstart = sf->sel->start.col;
 		divend = sf->sel->end.col;
 	} else {
@@ -320,7 +329,7 @@ dialog_cell_sort_ok (SortFlow *sf)
 		order_box_get_clause (sf->clauses [lp], &array [lp]);
 		if (strlen (txt)) {
 			division = -1;
-			if (sf->columns) {
+			if (sf->top) {
 				if (sf->header) {
 					division = divstart + string_pos_in_list(txt, sf->colnames_header);
 				} else {
@@ -336,14 +345,14 @@ dialog_cell_sort_ok (SortFlow *sf)
 			if (division < divstart || division > divend) {
 				gnumeric_notice (sf->wb,
 						 GNOME_MESSAGE_BOX_ERROR,
-						 sf->columns ?
+						 sf->top ?
 						 _("Column must be within range") :						_("Row must be within range"));
 				return TRUE;
 			}
 			array [lp].offset = division - divstart;
 		} else if (lp <= 0) {
 			gnumeric_notice (sf->wb, GNOME_MESSAGE_BOX_ERROR,
-					 sf->columns ?
+					 sf->top ?
 					 _("First column must be valid") :
 					 _("First row must be valid"));
 			return TRUE;
@@ -352,13 +361,21 @@ dialog_cell_sort_ok (SortFlow *sf)
 	}
 
 	if (sf->header) {
-		if (sf->columns)
+		if (sf->top)
 			sf->sel->start.row += 1;
 		else
 			sf->sel->start.col += 1;
 	}
-	cmd_sort (NULL, sf->sheet, sf->sel, array,
-		  sf->num_clause, sf->columns);
+
+	data = g_new (SortData, 1);
+	data->sheet = sf->sheet;
+	data->range = sf->sel;
+	data->num_clause = sf->num_clause;
+	data->clauses = array;
+	data->top = sf->top;
+	
+	cmd_sort (NULL, data);
+	
 
 	return FALSE;
 }
@@ -382,8 +399,8 @@ dialog_cell_sort_del_clause (SortFlow *sf)
 static void
 dialog_cell_sort_add_clause(SortFlow *sf, Workbook *wb)
 {
-	if ((sf->num_clause >= sf->max_col_clause && sf->columns)
-	    || (sf->num_clause >= sf->max_row_clause && !(sf->columns)))
+	if ((sf->num_clause >= sf->max_col_clause && sf->top)
+	    || (sf->num_clause >= sf->max_row_clause && !(sf->top)))
 		gnumeric_notice (sf->wb, GNOME_MESSAGE_BOX_ERROR,
 				 _("Can't add more than the selection length."));
 	else if (sf->num_clause >= MAX_CLAUSE)
@@ -420,7 +437,7 @@ dialog_cell_sort_header_toggled (GtkWidget *widget, SortFlow *sf)
 	sf->header = GTK_TOGGLE_BUTTON (widget)->active;
 	for (i = 0; i < sf->num_clause; i++) {
 		if (sf->header) {
-			if (sf->columns)
+			if (sf->top)
 				gtk_combo_set_popdown_strings
 					(GTK_COMBO (sf->clauses [i]->rangetext),
 					 g_list_copy (sf->colnames_header));
@@ -429,7 +446,7 @@ dialog_cell_sort_header_toggled (GtkWidget *widget, SortFlow *sf)
 					(GTK_COMBO (sf->clauses [i]->rangetext),
 					 g_list_copy (sf->rownames_header));
 		} else {
-			if (sf->columns)
+			if (sf->top)
 				gtk_combo_set_popdown_strings
 					(GTK_COMBO (sf->clauses [i]->rangetext),
 					 g_list_copy (sf->colnames_plain));
@@ -449,8 +466,8 @@ dialog_cell_sort_rows_toggled(GtkWidget *widget, SortFlow *sf)
 {
 	int i;
 
-	sf->columns = !(GTK_TOGGLE_BUTTON (widget)->active);
-	if (!(sf->columns)) {
+	sf->top = !(GTK_TOGGLE_BUTTON (widget)->active);
+	if (!(sf->top)) {
 		if (sf->num_clause > sf->max_row_clause)
 			dialog_cell_sort_set_clauses(sf, sf->max_row_clause);
 		for (i=0; i<sf->num_clause; i++) {
@@ -472,8 +489,8 @@ dialog_cell_sort_cols_toggled (GtkWidget *widget, SortFlow *sf)
 {
 	int i;
 
-	sf->columns = GTK_TOGGLE_BUTTON (widget)->active;
-	if ((sf->columns)) {
+	sf->top = GTK_TOGGLE_BUTTON (widget)->active;
+	if ((sf->top)) {
 		if (sf->num_clause > sf->max_col_clause)
 			dialog_cell_sort_set_clauses (sf, sf->max_col_clause);
 		for (i = 0; i < sf->num_clause; i++) {
@@ -521,7 +538,7 @@ dialog_cell_sort (Workbook *inwb, Sheet *sheet)
 	
 	/* Set up the dialog information */
 	sort_flow.header = FALSE;
-	sort_flow.columns = TRUE;
+	sort_flow.top = TRUE;
 	sort_flow.colnames_plain  = column_name_list (sort_flow.sheet, 
 						      sort_flow.sel->start.col,
 						      sort_flow.sel->end.col,
@@ -597,6 +614,11 @@ dialog_cell_sort (Workbook *inwb, Sheet *sheet)
 			    GTK_SIGNAL_FUNC (dialog_cell_sort_cols_toggled),
 			    &sort_flow);
 
+	/* Set the header button and drop down boxes correctly */
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
+				      range_has_header (sort_flow.sheet, 
+							sort_flow.sel, TRUE));
+
 	gtk_widget_show_all (sort_flow.clause_box);
 	
 	/* Run the dialog */
