@@ -1,10 +1,10 @@
 /*
- * dialog-solver.c: 
+ * dialog-solver.c:
  *
  * Author:
  *  Jukka-Pekka Iivonen <iivonen@iki.fi>
  *
- * (C) Copyright 2000 by Jukka-Pekka Iivonen <iivonen@iki.fi> 
+ * (C) Copyright 2000 by Jukka-Pekka Iivonen <iivonen@iki.fi>
  */
 
 #include <config.h>
@@ -19,7 +19,7 @@
 #include "tools.h"
 #include "value.h"
 #include "workbook.h"
-#include "gutils.h"
+#include "parse-util.h"
 #include "utils-dialog.h"
 
 /* Different constraint types */
@@ -46,14 +46,14 @@ typedef struct {
 static void
 linearmodel_toggled(GtkWidget *widget, Sheet *sheet)
 {
-        sheet->solver_parameters.options.assume_linear_model = 
+        sheet->solver_parameters.options.assume_linear_model =
 	        GTK_TOGGLE_BUTTON (widget)->active;
 }
 
 static void
 nonnegative_toggled(GtkWidget *widget, Sheet *sheet)
 {
-        sheet->solver_parameters.options.assume_non_negative = 
+        sheet->solver_parameters.options.assume_non_negative =
 	        GTK_TOGGLE_BUTTON (widget)->active;
 }
 
@@ -61,22 +61,20 @@ static void
 dialog_solver_options (Workbook *wb, Sheet *sheet)
 
 {
-	GladeXML  *gui = glade_xml_new (GNUMERIC_GLADEDIR 
-					"/solver-options.glade",
-					NULL);
+	GladeXML  *gui;
 	GtkWidget *dia;
 	GtkWidget *linearmodel;
 	GtkWidget *nonnegative;
 	gint      v, old_lm, old_nn;
 
+	gui = gnumeric_glade_xml_new (workbook_command_context_gui (wb),
+				"solver-options.glade");
+        if (gui == NULL)
+                return;
+
 	old_lm = sheet->solver_parameters.options.assume_linear_model;
 	old_nn = sheet->solver_parameters.options.assume_non_negative;
 
-	if (!gui) {
-		printf ("Could not find solver-options.glade\n");
-		return;
-	}
-	
 	dia = glade_xml_get_widget (gui, "SolverOptions");
 	if (!dia) {
 		printf ("Corrupt file solver-options.glade\n");
@@ -128,10 +126,10 @@ add_constraint(constraint_dialog_t *constraint_dialog,
 			      rhs_row, type_str, cols, rows);
 
 	constraint = g_new (SolverConstraint, 1);
-	constraint->lhs_col = lhs_col;
-	constraint->lhs_row = lhs_row;
-	constraint->rhs_col = rhs_col;
-	constraint->rhs_row = rhs_row;
+	constraint->lhs.col = lhs_col;
+	constraint->lhs.row = lhs_row;
+	constraint->rhs.col = rhs_col;
+	constraint->rhs.row = rhs_row;
 	constraint->cols = cols;
 	constraint->rows = rows;
 
@@ -140,10 +138,10 @@ add_constraint(constraint_dialog_t *constraint_dialog,
 	strcpy (constraint->type, type_str);
 	constraint->str = g_malloc (strlen (constraint_buf)+1);
 	strcpy (constraint->str, constraint_buf);
-	constraint_dialog->constraints = 
+	constraint_dialog->constraints =
 	        g_slist_append(constraint_dialog->constraints,
 			       (gpointer) constraint);
-	gtk_clist_set_row_data (constraint_dialog->clist, row, 
+	gtk_clist_set_row_data (constraint_dialog->clist, row,
 				(gpointer) constraint);
 
 	return 0;
@@ -153,8 +151,7 @@ add_constraint(constraint_dialog_t *constraint_dialog,
 static void
 constr_add_click (GtkWidget *widget, constraint_dialog_t *constraint_dialog)
 {
-	GladeXML  *gui = glade_xml_new (GNUMERIC_GLADEDIR "/solver.glade",
-					NULL);
+	GladeXML     *gui;
 	GtkWidget    *dialog;
 	GtkWidget    *lhs_entry;
 	GtkWidget    *rhs_entry;
@@ -170,11 +167,11 @@ constr_add_click (GtkWidget *widget, constraint_dialog_t *constraint_dialog)
 	int          rhs_cols, rhs_rows;
 	char         *type_str;
 
-	if (!gui) {
-		printf ("Could not find solver.glade\n");
-		return;
-	}
-	
+	gui = gnumeric_glade_xml_new (workbook_command_context_gui (constraint_dialog->wb),
+				"solver.glade");
+        if (gui == NULL)
+                return;
+
 	constraint_type_strs = add_strings_to_glist (constraint_strs);
 
 	dialog = glade_xml_get_widget (gui, "SolverAddConstraint");
@@ -195,7 +192,7 @@ constr_add_click (GtkWidget *widget, constraint_dialog_t *constraint_dialog)
 				      GTK_EDITABLE (combo_entry));
 	gnome_dialog_editable_enters (GNOME_DIALOG (dialog),
 				      GTK_EDITABLE (rhs_entry));
-	
+
 	gtk_widget_set_sensitive (combo_entry, FALSE);
 
 	gtk_combo_set_popdown_strings (GTK_COMBO (type_entry),
@@ -219,13 +216,13 @@ add_dialog:
 		gtk_widget_show (constraint_dialog->dialog);
 		return;
 	}
-	
+
 	lhs_text = gtk_entry_get_text (GTK_ENTRY (lhs_entry));
 	if (!parse_cell_name_or_range (lhs_text, &lhs_col, &lhs_row,
 				       &lhs_cols, &lhs_rows, TRUE)) {
 		gtk_widget_grab_focus (lhs_entry);
 		gtk_entry_set_position(GTK_ENTRY (lhs_entry), 0);
-		gtk_entry_select_region(GTK_ENTRY (lhs_entry), 0, 
+		gtk_entry_select_region(GTK_ENTRY (lhs_entry), 0,
 					GTK_ENTRY(lhs_entry)->text_length);
 		goto add_dialog;
 	}
@@ -239,7 +236,7 @@ add_dialog:
 				       &rhs_cols, &rhs_rows, TRUE)) {
 		gtk_widget_grab_focus (rhs_entry);
 		gtk_entry_set_position(GTK_ENTRY (rhs_entry), 0);
-		gtk_entry_select_region(GTK_ENTRY (rhs_entry), 0, 
+		gtk_entry_select_region(GTK_ENTRY (rhs_entry), 0,
 					GTK_ENTRY(rhs_entry)->text_length);
 		goto add_dialog;
 	}
@@ -293,8 +290,7 @@ constr_change_click (GtkWidget *widget, constraint_dialog_t *data)
 {
 	SolverConstraint *constraint;
 
-	GladeXML  *gui = glade_xml_new (GNUMERIC_GLADEDIR "/solver.glade",
-					NULL);
+	GladeXML  *gui;
 	GtkWidget *dia;
 	GtkWidget *lhs_entry;
 	GtkWidget *rhs_entry;
@@ -308,14 +304,14 @@ constr_change_click (GtkWidget *widget, constraint_dialog_t *data)
 	int       lhs_cols, lhs_rows;
 	int       rhs_cols, rhs_rows;
 
+	gui = gnumeric_glade_xml_new (workbook_command_context_gui (data->wb),
+				"solver.glade");
+        if (gui == NULL)
+                return;
+
 	if (selected_row < 0)
 	        return;
 
-	if (!gui) {
-		printf ("Could not find solver.glade\n");
-		return;
-	}
-	
 	constraint_type_strs = add_strings_to_glist (constraint_strs);
 
 	dia = glade_xml_get_widget (gui, "SolverChangeConstraint");
@@ -335,7 +331,7 @@ constr_change_click (GtkWidget *widget, constraint_dialog_t *data)
 				      GTK_EDITABLE (combo_entry));
 	gnome_dialog_editable_enters (GNOME_DIALOG (dia),
 				      GTK_EDITABLE (rhs_entry));
-	
+
 	gtk_widget_set_sensitive (combo_entry, FALSE);
 
 	gtk_combo_set_popdown_strings (GTK_COMBO (type_combo),
@@ -345,32 +341,28 @@ constr_change_click (GtkWidget *widget, constraint_dialog_t *data)
 	        gtk_clist_get_row_data (data->clist, selected_row);
 
 	if (constraint->cols == 1 && constraint->rows == 1)
-	        gtk_entry_set_text (GTK_ENTRY (lhs_entry), 
-				    cell_name (constraint->lhs_col, 
-					       constraint->lhs_row));
+	        gtk_entry_set_text (GTK_ENTRY (lhs_entry),
+				    cell_pos_name (&constraint->lhs));
 	else {
-	        sprintf(buf, "%s:", cell_name (constraint->lhs_col, 
-					       constraint->lhs_row));
-		strcat (buf, cell_name (constraint->lhs_col+
-					constraint->cols-1,
-					constraint->lhs_row+
-					constraint->rows-1));
+	        sprintf(buf, "%s:", cell_pos_name (&constraint->lhs));
+		strcat (buf, cell_coord_name (constraint->lhs.col+
+					      constraint->cols-1,
+					      constraint->lhs.row+
+					      constraint->rows-1));
 		gtk_entry_set_text (GTK_ENTRY (lhs_entry), buf);
 	}
 
 	if (strcmp (constraint->type, "Int") != 0 &&
 	    strcmp (constraint->type, "Bool") != 0) {
 	        if (constraint->cols == 1 && constraint->rows == 1)
-		        gtk_entry_set_text (GTK_ENTRY (rhs_entry), 
-					    cell_name (constraint->rhs_col, 
-						       constraint->rhs_row));
+		        gtk_entry_set_text (GTK_ENTRY (rhs_entry),
+					    cell_pos_name (&constraint->rhs));
 		else {
-		        sprintf(buf, "%s:", cell_name (constraint->rhs_col, 
-						       constraint->rhs_row));
-			strcat (buf, cell_name (constraint->rhs_col+
-						constraint->cols-1,
-						constraint->rhs_row+
-						constraint->rows-1));
+		        sprintf(buf, "%s:", cell_pos_name (&constraint->rhs));
+			strcat (buf, cell_coord_name (constraint->rhs.col+
+						      constraint->cols-1,
+						      constraint->rhs.row+
+						      constraint->rows-1));
 			gtk_entry_set_text (GTK_ENTRY (rhs_entry), buf);
 		}
 	}
@@ -378,7 +370,7 @@ constr_change_click (GtkWidget *widget, constraint_dialog_t *data)
 	gtk_entry_set_text (GTK_ENTRY (combo_entry), constraint->type);
 	gtk_widget_hide (data->dialog);
 	gtk_entry_set_position(GTK_ENTRY (lhs_entry), 0);
-	gtk_entry_select_region(GTK_ENTRY (lhs_entry), 0, 
+	gtk_entry_select_region(GTK_ENTRY (lhs_entry), 0,
 				GTK_ENTRY(lhs_entry)->text_length);
 
 	/* Run the dialog */
@@ -391,8 +383,7 @@ loop:
 	        gchar buf[512];
 	        gchar *constraint_str[2] = { buf, NULL };
 	        entry = gtk_entry_get_text (GTK_ENTRY (lhs_entry));
-		txt = (gchar *) cell_name (constraint->lhs_col,
-					   constraint->lhs_row);
+		txt = (gchar *) cell_pos_name (&constraint->lhs);
 		if (strcmp (entry, txt) != 0) {
 		        if (!parse_cell_name_or_range (entry, &col, &row,
 						       &lhs_cols, &lhs_rows, TRUE)) {
@@ -400,13 +391,13 @@ loop:
 				gtk_entry_set_position(GTK_ENTRY (lhs_entry),
 						       0);
 				gtk_entry_select_region(GTK_ENTRY (lhs_entry),
-							0, 
+							0,
 							GTK_ENTRY(lhs_entry)->
 							  text_length);
 				goto loop;
 			}
-			constraint->lhs_col = col;
-			constraint->lhs_row = row;
+			constraint->lhs.col = col;
+			constraint->lhs.row = row;
 		}
 
 		entry = gtk_entry_get_text (GTK_ENTRY (combo_entry));
@@ -418,22 +409,21 @@ loop:
 		        goto skip_rhs;
 
 		entry = gtk_entry_get_text (GTK_ENTRY (rhs_entry));
-		txt = (gchar *) cell_name (constraint->rhs_col,
-					   constraint->rhs_row);
+		txt = (gchar *) cell_pos_name (&constraint->rhs);
 		if (strcmp (entry, txt) != 0) {
-		        if (!parse_cell_name_or_range (entry, &col, &row, 
+		        if (!parse_cell_name_or_range (entry, &col, &row,
 						       &rhs_cols, &rhs_rows, TRUE)) {
 			        gtk_widget_grab_focus (rhs_entry);
 				gtk_entry_set_position(GTK_ENTRY (rhs_entry),
 						       0);
 				gtk_entry_select_region(GTK_ENTRY (rhs_entry),
-							0, 
+							0,
 							GTK_ENTRY(rhs_entry)->
 							  text_length);
 				goto loop;
 			}
-			constraint->rhs_col = col;
-			constraint->rhs_row = row;
+			constraint->rhs.col = col;
+			constraint->rhs.row = row;
 		}
 
 		if (lhs_cols != rhs_cols || lhs_rows != rhs_rows) {
@@ -459,16 +449,16 @@ loop:
 		constraint->cols = lhs_cols;
 		constraint->rows = lhs_rows;
 
-		write_constraint_str (buf, constraint->lhs_col,
-				      constraint->lhs_row, constraint->rhs_col,
-				      constraint->rhs_row, constraint->type,
+		write_constraint_str (buf, constraint->lhs.col,
+				      constraint->lhs.row, constraint->rhs.col,
+				      constraint->rhs.row, constraint->type,
 				      constraint->cols, constraint->rows);
 
 		constraint->str = g_malloc (strlen (buf)+1);
 		strcpy (constraint->str, buf);
 	        gtk_clist_remove (data->clist, selected_row);
 	        gtk_clist_insert (data->clist, selected_row, constraint_str);
-		gtk_clist_set_row_data (data->clist, selected_row, 
+		gtk_clist_set_row_data (data->clist, selected_row,
 					(gpointer) constraint);
 	}
 
@@ -490,7 +480,7 @@ constr_delete_click (GtkWidget *widget, gpointer data)
 	if (selected_row >= 0) {
 	        p = gtk_clist_get_row_data (constraint_dialog->clist,
 					    selected_row);
-		constraint_dialog->constraints = 
+		constraint_dialog->constraints =
 		        g_slist_remove (constraint_dialog->constraints, p);
 
 	        gtk_clist_remove (constraint_dialog->clist, selected_row);
@@ -552,8 +542,7 @@ static gboolean
 dialog_results (Workbook *wb, int res, gboolean ilp,
 		gboolean *answer, gboolean *sensitivity, gboolean *limits)
 {
-	GladeXML  *gui = glade_xml_new (GNUMERIC_GLADEDIR "/solver.glade",
-					NULL);
+	GladeXML  *gui;
 	GtkWidget *dialog;
 	GtkWidget *label;
 	GtkWidget *checkbutton1;
@@ -566,6 +555,11 @@ dialog_results (Workbook *wb, int res, gboolean ilp,
 	gboolean  keep_solver_solution;
 	int       selection;
 
+	gui = gnumeric_glade_xml_new (workbook_command_context_gui (wb),
+				"solver.glade");
+        if (gui == NULL)
+                return FALSE;
+
 	answer_s = sensitivity_s = limits_s = FALSE;
 
 	switch (res){
@@ -585,10 +579,6 @@ dialog_results (Workbook *wb, int res, gboolean ilp,
 	        break;
 	}
 
-	if (!gui) {
-		printf ("Could not find solver.glade\n");
-		return FALSE;
-	}
 	dialog = glade_xml_get_widget (gui, "SolverResults");
 	label = glade_xml_get_widget (gui, "result-label");
 	checkbutton1 = glade_xml_get_widget (gui, "checkbutton1");
@@ -607,10 +597,10 @@ dialog_results (Workbook *wb, int res, gboolean ilp,
 			    GTK_SIGNAL_FUNC (report_button_toggled), limits);
 
 	gtk_signal_connect (GTK_OBJECT (radiobutton3), "toggled",
-			    GTK_SIGNAL_FUNC (solver_values_toggled), 
+			    GTK_SIGNAL_FUNC (solver_values_toggled),
 			    &keep_solver_solution);
 	gtk_signal_connect (GTK_OBJECT (radiobutton4), "toggled",
-			    GTK_SIGNAL_FUNC (original_values_toggled), 
+			    GTK_SIGNAL_FUNC (original_values_toggled),
 			    &keep_solver_solution);
 
 	gtk_label_set_text (GTK_LABEL (label), label_txt);
@@ -655,7 +645,7 @@ restore_original_values (CellList *input_cells, GSList *ov)
 	        const char *str = (char *) ov->data;
 	        Cell *cell = (Cell *) input_cells->data;
 
-		cell_set_text (cell, str);
+		sheet_cell_set_text (cell, str);
 		ov = ov->next;
 		input_cells = input_cells->next;
 	}
@@ -674,8 +664,8 @@ check_int_constraints (CellList *input_cells, GSList *constraints, char **s)
 		    strcmp (c->type, "Bool") == 0) {
 		        for (cells = input_cells; cells; cells = cells->next) {
 			  cell = (Cell *) cells->data;
-			  if (cell->col->pos == c->lhs_col &&
-			      cell->row->pos == c->lhs_row)
+			  if (cell->col_info->pos == c->lhs.col &&
+			      cell->row_info->pos == c->lhs.row)
 			          goto ok;
 			}
 			*s = c->str;
@@ -690,10 +680,8 @@ check_int_constraints (CellList *input_cells, GSList *constraints, char **s)
 
 void
 dialog_solver (Workbook *wb, Sheet *sheet)
-
 {
-	GladeXML  *gui = glade_xml_new (GNUMERIC_GLADEDIR "/solver.glade",
-					NULL);
+	GladeXML  *gui;
 	GtkWidget *dialog;
 	GtkWidget *target_entry, *input_entry;
 	GtkWidget *radiobutton;
@@ -717,10 +705,11 @@ dialog_solver (Workbook *wb, Sheet *sheet)
 	int        error_flag, row;
 	gboolean   answer, sensitivity, limits;
 
-	if (!gui) {
-		printf ("Could not find solver.glade\n");
-		return;
-	}
+	gui = gnumeric_glade_xml_new (workbook_command_context_gui (wb),
+				"solver.glade");
+        if (gui == NULL)
+                return;
+
 	param = &sheet->solver_parameters;
 
 	constraint_dialog = g_new (constraint_dialog_t, 1);
@@ -728,13 +717,11 @@ dialog_solver (Workbook *wb, Sheet *sheet)
 
 	if (param->target_cell == NULL)
 	        target_entry_str =
-		  (gchar *) cell_name (sheet->cursor.edit_pos.col,
-				       sheet->cursor.edit_pos.row);
+		  (gchar *) cell_pos_name (&sheet->cursor.edit_pos);
 	else
 	        target_entry_str =
-		  (gchar *) cell_name (param->target_cell->col->pos,
-				       param->target_cell->row->pos);
-		  
+		  (gchar *) cell_name (param->target_cell);
+
 	dialog = glade_xml_get_widget (gui, "Solver");
 	target_entry = glade_xml_get_widget (gui, "target-cell");
 	input_entry = glade_xml_get_widget (gui, "input-cells");
@@ -808,18 +795,18 @@ dialog_solver (Workbook *wb, Sheet *sheet)
 		gchar buf[256];
 	        gchar *tmp[] = { buf, NULL };
 
-		write_constraint_str (buf, c->lhs_col, c->lhs_row, c->rhs_col,
-				      c->rhs_row, c->type, c->cols, c->rows);
+		write_constraint_str (buf, c->lhs.col, c->lhs.row, c->rhs.col,
+				      c->rhs.row, c->type, c->cols, c->rows);
 
 	        gtk_clist_append (GTK_CLIST (constraint_list), tmp);
-		gtk_clist_set_row_data (GTK_CLIST (constraint_list), row++, 
+		gtk_clist_set_row_data (GTK_CLIST (constraint_list), row++,
 					(gpointer) c);
 	}
 
 	gtk_widget_grab_focus (target_entry);
 
 main_dialog:
-	
+
 	/* Run the dialog */
 	selection = gnumeric_dialog_run (wb, GNOME_DIALOG (dialog));
 
@@ -849,7 +836,7 @@ main_dialog:
 	        dialog_solver_options (wb, sheet);
 		goto main_dialog;
 
-		
+
 	default:
 	        break;
 	}
@@ -862,7 +849,7 @@ main_dialog:
 				   "for 'Target cell'"));
 		gtk_widget_grab_focus (target_entry);
 		gtk_entry_set_position(GTK_ENTRY (target_entry), 0);
-		gtk_entry_select_region(GTK_ENTRY (target_entry), 0, 
+		gtk_entry_select_region(GTK_ENTRY (target_entry), 0,
 					GTK_ENTRY(target_entry)->text_length);
 		goto main_dialog;
 	}
@@ -870,7 +857,7 @@ main_dialog:
 	if (target_cell == NULL) {
 	        target_cell = sheet_cell_new (sheet, target_cell_col,
 					      target_cell_row);
-		cell_set_text (target_cell, "");
+		sheet_cell_set_value (target_cell, value_new_empty(), NULL);
 	}
 	ov_target = value_get_as_float (target_cell->value);
 
@@ -885,7 +872,7 @@ main_dialog:
 				   "in 'By changing cells'"));
 		gtk_widget_grab_focus (input_entry);
 		gtk_entry_set_position(GTK_ENTRY (input_entry), 0);
-		gtk_entry_select_region(GTK_ENTRY (input_entry), 0, 
+		gtk_entry_select_region(GTK_ENTRY (input_entry), 0,
 					GTK_ENTRY(input_entry)->text_length);
 		goto main_dialog;
 	}
@@ -898,7 +885,7 @@ main_dialog:
 		gboolean ilp;
 		char     *s;
 
-		if (check_int_constraints (input_cells, 
+		if (check_int_constraints (input_cells,
 					   constraint_dialog->constraints,
 					   &s)) {
 		        static char buf[1024];
