@@ -90,7 +90,7 @@ struct _ExprArray {
 	int       ref_count;
 
 	int   x, y;
-	int   rows, cols;
+	int   cols, rows;
 	union {
 		/* Upper left corner */
 		struct {
@@ -147,9 +147,9 @@ struct _NamedExpression {
 };
 
 ExprTree   *expr_parse_string      (char const *expr, ParsePos const *pp,
-				    char **desired_format, char **error_msg);
+				    StyleFormat **desired_format, char **error_msg);
 ExprTree   *expr_tree_duplicate    (ExprTree *expr);
-char       *expr_decode_tree       (ExprTree *tree, ParsePos const *fp);
+char       *expr_tree_as_string    (ExprTree const *tree, ParsePos const *fp);
 
 ExprTree   *expr_tree_new_constant (Value *v);
 ExprTree   *expr_tree_new_error    (char const *txt);
@@ -191,9 +191,6 @@ ExprTree       *expr_rewrite (ExprTree        const *expr,
 int             expr_tree_get_const_int (ExprTree const *expr);
 char const *	expr_tree_get_const_str (ExprTree const *expr);
  
-/* Debugging */ 
-void expr_dump_tree (ExprTree const *tree);
-
 /*
  * Returns int(0) if the expression uses a non-existant cell for anything
  * other than an equality test.
@@ -212,6 +209,9 @@ Value       *eval_expr (EvalPos const *pos,
 Value       *expr_implicit_intersection (EvalPos const *pos,
 					 Value *v);
 
+FunctionDefinition *expr_tree_get_func_def (ExprTree const *expr);
+ExprTree const *    expr_tree_first_func (ExprTree const *expr);
+
 /* Setup of the symbol table */
 void         functions_init        (void);
 void         constants_init        (void);
