@@ -226,11 +226,7 @@ workbook_try_read (CommandContext *context, const char *filename)
 	wb = workbook_new ();
 	result = workbook_load_from (context, wb, filename);
 	if (result != 0) {
-#ifdef ENABLE_BONOBO
-		bonobo_object_destroy (BONOBO_OBJECT (wb));
-#else
 		gtk_object_destroy   (GTK_OBJECT (wb));
-#endif
 		wb = NULL;
 	}
 
@@ -271,7 +267,7 @@ Workbook *
 workbook_read (CommandContext *context, const char *filename)
 {
 	Workbook *wb = NULL;
-	char * template;
+	char *template;
 
 	g_return_val_if_fail (filename != NULL, NULL);
 
@@ -348,7 +344,7 @@ workbook_import (CommandContext *context, Workbook *parent,
 		
 	gtk_widget_grab_focus (GTK_WIDGET (clist));
 
-	ret = gnumeric_dialog_run (wb, GNOME_DIALOG (dialog));
+	ret = gnumeric_dialog_run (parent, GNOME_DIALOG (dialog));
 
 	if (ret == 0 && clist->selection) {
 		int sel_row;
@@ -361,7 +357,7 @@ workbook_import (CommandContext *context, Workbook *parent,
 		gnome_dialog_close (GNOME_DIALOG (dialog));
 		
 	if (fo) {
-		char * template;
+		char *template;
 
 		wb = workbook_new ();
 		template = g_strdup_printf (_("Could not import file %s\n%%s"),
@@ -371,11 +367,7 @@ workbook_import (CommandContext *context, Workbook *parent,
 		command_context_pop_template (context);
 		g_free (template);
 		if (ret != 0) {
-#ifdef ENABLE_BONOBO
-		        bonobo_object_destroy (BONOBO_OBJECT (wb));
-#else
 			gtk_object_destroy   (GTK_OBJECT (wb));
-#endif
 			wb = NULL;
 		} else
 			workbook_set_dirty (wb, FALSE);
