@@ -479,10 +479,10 @@ lookup_color (const char *str, const char *end)
 	int i;
 
 	for (i = 0; format_colors [i].name; i++){
-		int len = strlen (format_colors [i].name);
-
-		if ((strncasecmp (format_colors [i].name, str, len) == 0) ||
-		    (strncasecmp (_(format_colors [i].name), str, len) == 0)){
+		char const *pre = _(format_colors [i].name);
+		char const *post = _(pre);
+		if ((strcasecmp (format_colors [i].name, str) == 0) ||
+		    (pre != post && strcasecmp (_(format_colors [i].name), str) == 0)){
 			style_color_ref (format_colors [i].color);
 			return format_colors [i].color;
 		}
@@ -754,8 +754,8 @@ format_add_thousand (const char *format_string)
  * Finds the decimal char in @str doing the proper parsing of a
  * format string
  */
-static const char *
-find_decimal_char (const char *str)
+static char const *
+find_decimal_char (char const *str)
 {
 	char dc = DECIMAL_CHAR_OF_LC (lc);
 
@@ -817,7 +817,8 @@ char *
 format_remove_decimal (const char *format_string)
 {
 	int offset = 1;
-	char *ret, *t, *p;
+	char *ret, *p;
+	char const *tmp;
 
 	if (!lc)
 		lc = localeconv ();
@@ -831,12 +832,11 @@ format_remove_decimal (const char *format_string)
 	if (strcmp (format_string, "General") == 0)
 		format_string = "0.########";
 
-	ret = g_strdup (format_string);
-	p = (char *) find_decimal_char (ret);
-	if (!p){
-		g_free (ret);
+	tmp = find_decimal_char (format_string);
+	if (!tmp)
 		return NULL;
-	}
+
+	ret = p = g_strdup (tmp);
 
 	/* If there is more than 1 thing after the decimal place
 	 * leave the decimal.
@@ -847,8 +847,7 @@ format_remove_decimal (const char *format_string)
 	else
 		offset = 2;
 
-	for (t = p; *t; ++t)
-		*t = *(t+offset);
+	strcpy (p, p + offset);
 
 	return ret;
 }
@@ -1050,6 +1049,13 @@ format_number (gdouble number, const StyleFormatEntry *style_format_entry)
 				/* TODO TODO TODO : Do we need any more chars here ?? */
 				if (format[1] == '-')
 					info.supress_minus = TRUE;
+				else if (can_render_number && !info.rendered) {
+					char *s;
+					s = do_render_number (number, &info);
+					g_string_append (result, s);
+					g_free (s);
+				}
+
 				format++;
 				g_string_append_c (result, *format);
 			}
@@ -1387,7 +1393,7 @@ format_value (StyleFormat *format, const Value *value, StyleColor **color,
 	switch (value->type){
 	case VALUE_FLOAT:
 		if (finite (value->v_float.val)) {
-			if (is_general){
+			if (is_general) {
 				/* FIXME FIXME FIXME : This is pathetic
 				 * rendering for General should be done
 				 * with knowledge of the cell width to
