@@ -12,7 +12,7 @@
 #include <limits.h>
 #include "complex.h"
 #include "gnumeric.h"
-#include "gutils.h"
+#include "parse-util.h"
 #include "func.h"
 #include "mathfunc.h"
 
@@ -74,18 +74,18 @@ val_to_base (FunctionEvalInfo *ei, Value **argv, int num_argv,
 		return value_duplicate(value);
 
 	case VALUE_STRING:
-		str = value->v.str->str;
+		str = value->v_str.val->str;
 		break;
 	case VALUE_BOOLEAN :
-		snprintf (buffer, sizeof (buffer)-1, "%d", value->v.v_bool?1:0);
+		snprintf (buffer, sizeof (buffer)-1, "%d", value->v_bool.val?1:0);
 		str = buffer;
 		break;
 	case VALUE_INTEGER:
-		snprintf (buffer, sizeof (buffer)-1, "%d", value->v.v_int);
+		snprintf (buffer, sizeof (buffer)-1, "%d", value->v_int.val);
 		str = buffer;
 		break;
 	case VALUE_FLOAT:
-		snprintf (buffer, sizeof (buffer)-1, "%8.0f", value->v.v_float);
+		snprintf (buffer, sizeof (buffer)-1, "%8.0f", value->v_float.val);
 		str = buffer;
 		break;
 	case VALUE_EMPTY:
@@ -662,7 +662,7 @@ gnumeric_complex (FunctionEvalInfo *ei, Value **argv)
 	if (argv[2] == NULL)
 	        suffix = "i";
 	else
-	        suffix = argv[2]->v.str->str;
+	        suffix = argv[2]->v_str.val->str;
 
 	if (strcmp(suffix, "i") != 0 &&
 	    strcmp(suffix, "j") != 0)
@@ -1181,7 +1181,7 @@ typedef struct {
 } eng_imoper_t;
 
 static Value *
-callback_function_imoper (const EvalPosition *ep, Value *value, void *closure)
+callback_function_imoper (const EvalPos *ep, Value *value, void *closure)
 {
         eng_imoper_t *result = closure;
 	complex_t c;
@@ -1400,7 +1400,7 @@ static Value *
 convert (eng_convert_unit_t units[],
 	 eng_convert_unit_t prefixes[],
 	 char *from_unit, char *to_unit,
-	 float_t n, Value **v, const EvalPosition *ep)
+	 float_t n, Value **v, const EvalPos *ep)
 {
         float_t from_c, from_prefix, to_c, to_prefix;
 
@@ -1606,8 +1606,8 @@ gnumeric_convert (FunctionEvalInfo *ei, Value **argv)
 	Value   *v;
 
 	n = value_get_as_float (argv [0]);
-	from_unit = argv [1]->v.str->str;
-	to_unit = argv [2]->v.str->str;
+	from_unit = argv [1]->v_str.val->str;
+	to_unit = argv [2]->v_str.val->str;
 
 	if (strcmp(from_unit, "C") == 0 && strcmp(to_unit, "F") == 0)
 	        return value_new_float (1.8*n+32);
@@ -1766,11 +1766,10 @@ gnumeric_delta (FunctionEvalInfo *ei, Value **argv)
 		vy = value_new_int (0);
 
 	/* Promote to the largest value */
-	switch ((vx->type > vy->type) ? vx->type : vy->type)
-	{
+	switch ((vx->type > vy->type) ? vx->type : vy->type) {
 	case VALUE_BOOLEAN:
 		/* Only happens when both are bool */
-		ans = vx->v.v_bool == vy->v.v_bool;
+		ans = vx->v_bool.val == vy->v_bool.val;
 		break;
 	case VALUE_EMPTY:
 	case VALUE_INTEGER:
@@ -1821,11 +1820,10 @@ gnumeric_gestep (FunctionEvalInfo *ei, Value **argv)
 		vy = value_new_int (0);
 
 	/* Promote to the largest value */
-	switch ((vx->type > vy->type) ? vx->type : vy->type)
-	{
+	switch ((vx->type > vy->type) ? vx->type : vy->type) {
 	case VALUE_BOOLEAN:
 		/* Only happens when both are bool */
-		ans = vx->v.v_bool >= vy->v.v_bool;
+		ans = vx->v_bool.val >= vy->v_bool.val;
 		break;
 	case VALUE_EMPTY:
 	case VALUE_INTEGER:
