@@ -186,7 +186,7 @@ gnumeric_choose (FunctionEvalInfo *ei, GList *l)
 
 static char *help_vlookup = {
 	N_("@FUNCTION=VLOOKUP\n"
-	   "@SYNTAX=VLOOKUP(value,range,column,[approximate])\n"
+	   "@SYNTAX=VLOOKUP(value,range,column[,approximate])\n"
 
 	   "@DESCRIPTION="
 	   "VLOOKUP function finds the row in range that has a first "
@@ -342,7 +342,7 @@ gnumeric_vlookup (FunctionEvalInfo *ei, Value **args)
 
 static char *help_hlookup = {
 	N_("@FUNCTION=HLOOKUP\n"
-	   "@SYNTAX=HLOOKUP(value,range,row,[approximate])\n"
+	   "@SYNTAX=HLOOKUP(value,range,row[,approximate])\n"
 
 	   "@DESCRIPTION="
 	   "HLOOKUP function finds the col in range that has a first "
@@ -669,7 +669,7 @@ gnumeric_match (FunctionEvalInfo *ei, Value **args)
 
 static char *help_indirect = {
 	N_("@FUNCTION=INDIRECT\n"
-	   "@SYNTAX=INDIRECT(ref_text, [format])\n"
+	   "@SYNTAX=INDIRECT(ref_text,[format])\n"
 
 	   "@DESCRIPTION="
 	   "INDIRECT function returns the contents of the cell pointed to "
@@ -677,7 +677,7 @@ static char *help_indirect = {
 	   "reference the format of which is either A1 or R1C1 style. The "
 	   "style is set by the format boolean, which defaults to the former."
 	   "\n"
-	   "If ref_text is not a valid reference returns #REF! "
+	   "If @ref_text is not a valid reference returns #REF! "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
@@ -738,7 +738,7 @@ gnumeric_indirect (FunctionEvalInfo *ei, Value **args)
  */
 static char *help_index = {
 	N_("@FUNCTION=INDEX\n"
-	   "@SYNTAX=INDEX(reference, [row, col, area])\n"
+	   "@SYNTAX=INDEX(reference,[row, col, area])\n"
 
 	   "@DESCRIPTION="
 	   "The INDEX function returns a reference to the cell at a offset "
