@@ -75,7 +75,6 @@ callback_function_criteria (Sheet *sheet, int col, int row,
 {
         math_criteria_t *mm = user_data;
 	Value           *v;
-	gpointer        n;
 
 	mm->total_num++;
 	if (cell == NULL || cell->value == NULL)
@@ -101,10 +100,8 @@ callback_function_criteria (Sheet *sheet, int col, int row,
 
 	if (mm->fun(v, mm->test_value)) {
 	        if (mm->actual_range) {
-			n = g_new (int, 1);
-			*((int *) n) = mm->total_num;
-		        mm->list = g_slist_append (mm->list, n);
-			/* FIXME: is this right?  -- MW.  */
+		        mm->list = g_slist_append (mm->list,
+				GINT_TO_POINTER (mm->total_num));
 			value_release(v);
 		} else
 		        mm->list = g_slist_append (mm->list, v);
@@ -580,46 +577,34 @@ callback_function_sumif (Sheet *sheet, int col, int row,
 			 Cell *cell, void *user_data)
 {
         math_criteria_t *mm = user_data;
-	float_t         v;
-	int             num;
-
-	mm->total_num++;
-	if (cell == NULL || cell->value == NULL)
-	        return NULL;
-
-        switch (cell->value->type) {
-	case VALUE_INTEGER:
-	        v = cell->value->v_int.val;
-		break;
-	case VALUE_FLOAT:
-	        v = cell->value->v_float.val;
-		break;
-	case VALUE_STRING:
-	        v = 0;
-		break;
-
-	case VALUE_BOOLEAN:
-	        v = cell->value->v_bool.val ? 1 : 0;
-		break;
-
-	case VALUE_ERROR:
-		return value_terminate();
-
-	case VALUE_EMPTY:
-	default:
-	        return NULL;
-	}
+	float_t         v = 0.;
 
+	/* If we have finished the list there is no need to bother */
 	if (mm->current == NULL)
 	        return NULL;
 
-	num = *((int*) mm->current->data);
+	/* We have not reached the next selected element yet.
+	 * This implies that summing a range containing an error
+	 * where the criteria does not select the error is OK.
+	 */
+	if (++(mm->total_num) != GPOINTER_TO_INT (mm->current->data))
+		return NULL;
 
-	if (mm->total_num == num) {
-	        mm->sum += v;
-		g_free(mm->current->data);
-		mm->current=mm->current->next;
-	}
+	if (cell != NULL && cell->value != NULL)
+		switch (cell->value->type) {
+		case VALUE_BOOLEAN:	v = cell->value->v_bool.val ? 1 : 0; break;
+		case VALUE_INTEGER:	v = cell->value->v_int.val; break;
+		case VALUE_FLOAT:	v = cell->value->v_float.val; break;
+
+		case VALUE_STRING:
+		case VALUE_EMPTY:
+			break;
+
+		default:
+			return value_terminate();
+		}
+	mm->sum += v;
+	mm->current = mm->current->next;
 
 	return NULL;
 }
@@ -640,10 +625,13 @@ gnumeric_sumif (FunctionEvalInfo *ei, Value **argv)
 	items.total_num = 0;
 	items.list = NULL;
 
-	if ((!VALUE_IS_NUMBER(argv[1]) && argv[1]->type != VALUE_STRING)
-	    || (range->type != VALUE_CELLRANGE))
+	if (range->type != VALUE_CELLRANGE ||
+	    !(VALUE_IS_NUMBER (argv[1]) || argv[1]->type == VALUE_STRING))
 	        return value_new_error (ei->pos, gnumeric_err_VALUE);
 
+	/* If the criteria is a number test for equality else the parser
+	 * will evaluate the condition as a string
+	 */
 	if (VALUE_IS_NUMBER(argv[1])) {
 	        items.fun = (criteria_test_fun_t) criteria_test_equal;
 		items.test_value = argv[1];
@@ -653,10 +641,7 @@ gnumeric_sumif (FunctionEvalInfo *ei, Value **argv)
 		tmpval = items.test_value;
 	}
 
-	if (actual_range != NULL)
-	        items.actual_range = TRUE;
-	else
-	        items.actual_range = FALSE;
+	items.actual_range = (actual_range != NULL);
 
 	ret = sheet_cell_foreach_range (
 		eval_sheet (range->v_range.cell.a.sheet, ei->pos->sheet),
@@ -1347,18 +1332,18 @@ gnumeric_randbinom (FunctionEvalInfo *ei, Value **argv)
 /***************************************************************************/
 
 static char *help_randnegbinom = {
-        N_("@FUNCTION=RandNegBinom\n"
-           "@SYNTAX=RandNegBinom(p,failures)\n"
+        N_("@FUNCTION=RANDNEGBINOM\n"
+           "@SYNTAX=RANDNEGBINOM(p,failures)\n"
 
            "@DESCRIPTION="
-           "RandNegBinom returns a negitive binomialy distributed random "
+           "RANDNEGBINOM returns a negitive binomialy distributed random "
            "number. "
            "\n"
-           "If @p < 0 or @p > 1 RandNegBinom returns #NUM! error. "
-           "If @failures RandNegBinom returns #NUM! error. "
+           "If @p < 0 or @p > 1, RANDNEGBINOM returns #NUM! error. "
+           "If @failures RANDNEGBINOM returns #NUM! error. "
 	   "\n"
            "@EXAMPLES=\n"
-           "RandNegBinom(0.5,2).\n"
+           "RANDNEGBINOM(0.5,2).\n"
            "\n"
            "@SEEALSO=RAND,RANDBETWEEN")
 };
@@ -2124,13 +2109,10 @@ gnumeric_round (FunctionEvalInfo *ei, Value **argv)
         int     digits;
 
 	number = value_get_as_float (argv[0]);
-	if (argv[1] == NULL)
-	        digits = 0;
-	else
-	        digits = value_get_as_int (argv[1]);
+	digits = argv[1] ? value_get_as_int (argv[1]) : 0;
 
 	p10 = gpow10 (digits);
-	return value_new_float (rint (number * p10) / p10);
+	return value_new_float (floor (number * p10 + (number >= 0 ? 0.5 : -0.5)) / p10);
 }
 
 /***************************************************************************/
@@ -3228,7 +3210,7 @@ static char *help_mdeterm = {
 	   "@EXAMPLES=\n"
 	   "Let us assume that A1, ..., A4 contain numbers 2, 3, 7, and 3, "
 	   "B1, ..., B4 4, 2, 4, and 1, C1, ..., C4 9, 4, 3, and 2, and "
-	   "D1, ..., D4 7, 3, 6, and 5.  Then.\n"
+	   "D1, ..., D4 7, 3, 6, and 5. Then\n"
 	   "MDETERM(A1:D4) equals 148.\n"
 	   "\n"
 	   "@SEEALSO=MMULT, MINVERSE")
@@ -3281,7 +3263,7 @@ static char *help_sumproduct = {
 	   "products.  If an array entry is not numeric, the value zero is "
 	   "used instead. "
 	   "\n"
-	   "If array or range arguments do not have the same dimentions, "
+	   "If arrays or range arguments do not have the same dimentions, "
 	   "SUMPRODUCT returns #VALUE! error. "
 	   "This function is Excel compatible. "
 	   "\n"
@@ -3307,10 +3289,10 @@ callback_function_sumproduct (const EvalPos *ep, Value *value,
 	math_sumproduct_t *mm = closure;
 	float_t           x;
 
-	if (!VALUE_IS_NUMBER (value))
-		x = 0;
-	else
+	if (value != NULL && VALUE_IS_NUMBER (value))
 	        x = value_get_as_float (value);
+	else
+		x = 0;
 
 	if (mm->first) {
 	        gpointer p;
@@ -3328,22 +3310,21 @@ callback_function_sumproduct (const EvalPos *ep, Value *value,
 }
 
 static Value *
-gnumeric_sumproduct (FunctionEvalInfo *ei, GList *expr_node_list)
+gnumeric_sumproduct (FunctionEvalInfo *ei, GList *args)
 {
         math_sumproduct_t p;
 	GSList            *current;
-	float_t           sum;
+	float_t           sum = 0.;
 	Value            *result=NULL;
 
-	if (expr_node_list == NULL)
+	if (args == NULL)
 		return value_new_error (ei->pos, gnumeric_err_NUM);
 
 	p.components = NULL;
 	p.first      = TRUE;
 
-	for ( ; result == NULL && expr_node_list;
-	      expr_node_list = expr_node_list->next) {
-		ExprTree *tree = (ExprTree *) expr_node_list->data;
+	for ( ; result == NULL && args; args = args->next) {
+		ExprTree *tree = (ExprTree *) args->data;
 		Value    *val;
 
 		val = eval_expr (ei->pos, tree, EVAL_PERMIT_NON_SCALAR);
@@ -3352,7 +3333,7 @@ gnumeric_sumproduct (FunctionEvalInfo *ei, GList *expr_node_list)
 		        p.current = p.components;
 			result = function_iterate_do_value (
 				ei->pos, callback_function_sumproduct, &p,
-				val, TRUE);
+				val, FALSE, FALSE);
 
 			value_release (val);
 		} else
@@ -3360,16 +3341,19 @@ gnumeric_sumproduct (FunctionEvalInfo *ei, GList *expr_node_list)
 		p.first = FALSE;
 	}
 
-	sum = 0;
-	for (current=p.components; current != NULL ; current = current->next) {
-	        gpointer p = current->data;
-	        sum += *((float_t *) p);
-		g_free(current->data);
+	if (result == NULL) {
+		sum = 0;
+		for (current = p.components; current != NULL ; current = current->next) {
+			gpointer p = current->data;
+			sum += *((float_t *) p);
+			g_free(current->data);
+		}
 	}
 	
 	g_slist_free(p.components);
 
-	if (expr_node_list)
+	/* If something was a different size */
+	if (result != NULL)
 		return value_new_error (ei->pos, gnumeric_err_VALUE);
 
 	return value_new_float (sum);
