@@ -492,7 +492,7 @@ gnumeric_find (FunctionEvalInfo *ei, Value **argv)
 
 static char *help_fixed = {
 	N_("@FUNCTION=FIXED\n"
-	   "@SYNTAX=FIXED(num, [decimals, no_commas])\n"
+	   "@SYNTAX=FIXED(num,[decimals, no_commas])\n"
 	   "@DESCRIPTION="
 	   "FIXED returns @num as a formatted string with @decimals numbers "
 	   "after the decimal point, omitting commas if requested by "
@@ -756,8 +756,7 @@ gnumeric_text (FunctionEvalInfo *ei, Value **args)
 	}
 
 	if (arg->type == VALUE_STRING) {
-		char *format = NULL;
-		Value *match = format_match (arg->v_str.val->str, &format);
+		Value *match = format_match (arg->v_str.val->str, NULL);
 		ok = (match != NULL);
 		if (ok)
 			tmp = match;
@@ -813,7 +812,7 @@ gnumeric_expression (FunctionEvalInfo *ei, Value **args)
 		if (cell_has_expr (cell)) {
 			ParsePos pos;
 			char * expr_string =
-			    expr_decode_tree (cell->u.expression,
+			    expr_tree_as_string (cell->u.expression,
 				parse_pos_init_evalpos (&pos, ei->pos));
 			Value * res = value_new_string (expr_string);
 			g_free (expr_string);
@@ -894,7 +893,6 @@ gnumeric_value (FunctionEvalInfo *ei, Value **argv)
 {
 	char *arg, *p, *q;
 	Value *v;
-	char *format;
 
 	switch (argv[0]->type) {
 	case VALUE_EMPTY:
@@ -911,7 +909,7 @@ gnumeric_value (FunctionEvalInfo *ei, Value **argv)
 		}
 		*q = 0;
 
-		v = format_match (arg, &format);
+		v = format_match (arg, NULL);
 		free (arg);
 
 		if (v)
@@ -1039,7 +1037,7 @@ gnumeric_substitute (FunctionEvalInfo *ei, Value **argv)
 
 static char *help_dollar = {
 	N_("@FUNCTION=DOLLAR\n"
-	   "@SYNTAX=DOLLAR(num,[decimals])\n"
+	   "@SYNTAX=DOLLAR(num[,decimals])\n"
 	   "@DESCRIPTION="
 	   "DOLLAR returns @num formatted as currency."
 	   "\n"
