@@ -42,7 +42,7 @@ gnumeric_notice (Workbook *wb, const char *type, const char *str)
 /**
  * gnumeric_wb_dialog_run : A utility routine to handle the
  * application being closed by the window manager while a modal dialog
- * is being displayed. 
+ * is being displayed.
  */
 static gint
 gnumeric_wb_dialog_run (Workbook *wb, GnomeDialog *dialog)
@@ -50,8 +50,9 @@ gnumeric_wb_dialog_run (Workbook *wb, GnomeDialog *dialog)
 	gint res;
 	GtkObject * const app = GTK_OBJECT (wb->toplevel);
 
-	gnome_dialog_set_parent (GNOME_DIALOG (dialog),
-				 GTK_WINDOW (wb->toplevel));
+	if (GTK_WINDOW (dialog)->transient_parent != GTK_WINDOW (wb->toplevel))
+		gnome_dialog_set_parent (GNOME_DIALOG (dialog),
+					 GTK_WINDOW (wb->toplevel));
 
 	gtk_object_ref (app);
 	res = gnome_dialog_run (dialog);
@@ -243,6 +244,69 @@ gnumeric_combo_enters (GtkWindow *window, GtkCombo *combo)
 				  GTK_EDITABLE (combo->entry));
 }
 
+/**
+ * gnumeric_toolbar_insert_with_eventbox
+ * @toolbar               toolbar
+ * @widget                widget to insert
+ * @tooltip_text          tooltip text
+ * @tooltip_private_text  longer tooltip text
+ * @position              widget position in toolbar
+ *
+ * Packs widget in an eventbox and adds the eventbox to toolbar.
+ * This lets a windowless widget (e.g. combo box) have tooltips.
+ **/
+void
+gnumeric_toolbar_insert_with_eventbox (GtkToolbar *toolbar, GtkWidget  *widget,
+				       const char *tooltip_text,
+				       const char *tooltip_private_text,
+				       gint        position)
+{
+	GtkWidget *eventbox;
+
+	g_return_if_fail (GTK_IS_TOOLBAR (toolbar));
+	g_return_if_fail (widget != NULL);
+	g_return_if_fail (position >= 0);
+	g_return_if_fail (position <= toolbar->num_children);
+
+	/* An event box to receive events - this is a requirement for having
+           tooltips */
+	eventbox = gtk_event_box_new ();
+	gtk_container_add (GTK_CONTAINER (eventbox), widget);
+	gtk_widget_show (eventbox);
+	gtk_toolbar_insert_widget (GTK_TOOLBAR (toolbar), eventbox,
+				   tooltip_text, tooltip_private_text,
+				   position);
+}
+
+/**
+ * gnumeric_toolbar_append_with_eventbox
+ * @toolbar               toolbar
+ * @widget                widget to insert
+ * @tooltip_text          tooltip text
+ * @tooltip_private_text  longer tooltip text
+ *
+ * Packs widget in an eventbox and adds the eventbox to toolbar.
+ * This lets a windowless widget (e.g. combo box) have tooltips.
+ **/
+void
+gnumeric_toolbar_append_with_eventbox (GtkToolbar *toolbar, GtkWidget  *widget,
+				       const char *tooltip_text,
+				       const char *tooltip_private_text)
+{
+	GtkWidget *eventbox;
+
+	g_return_if_fail (GTK_IS_TOOLBAR (toolbar));
+	g_return_if_fail (widget != NULL);
+
+	/* An event box to receive events - this is a requirement for having
+           tooltips */
+	eventbox = gtk_event_box_new ();
+	gtk_container_add (GTK_CONTAINER (eventbox), widget);
+	gtk_widget_show (eventbox);
+	gtk_toolbar_append_widget (GTK_TOOLBAR (toolbar), eventbox,
+				   tooltip_text, tooltip_private_text);
+}
+
 int
 gtk_radio_group_get_selected (GSList *radio_group)
 {
@@ -269,6 +333,8 @@ gtk_radio_button_select (GSList *group, int n)
 	GSList *l;
 	int len = g_slist_length (group);
 
+	g_return_if_fail ((n >= 0) && n < len);
+	
 	l = g_slist_nth (group, len - n - 1);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (l->data), 1);
 }
@@ -505,6 +571,45 @@ gnumeric_clist_make_selection_visible (GtkCList *clist)
 	}
 }
 
+/**
+ * gnumeric_option_menu_get_selected_index:
+ * @optionmenu: a gtkoptionmenu
+ * 
+ * Tries to find out (in an ugly way) the selected
+ * item in @optionsmenu
+ * 
+ * Return value: the selected index or -1 on error (or no selection?)
+ **/
+int
+gnumeric_option_menu_get_selected_index (GtkOptionMenu *optionmenu)
+{
+	GtkMenu *menu;
+	GtkMenuItem *selected;
+	GList *iterator;
+	int index = -1;
+	int i = 0;
+
+	g_return_val_if_fail (optionmenu != NULL, -1);
+	
+	menu = (GtkMenu *) gtk_option_menu_get_menu (optionmenu);
+	iterator = GTK_MENU_SHELL (menu)->children;
+	selected = (GtkMenuItem *) gtk_menu_get_active (menu);
+	
+	while (iterator) {
+		
+		if (iterator->data == selected) {
+		
+			index = i;
+			break;
+		}
+		
+		iterator = iterator->next;
+		i++;
+	}
+
+	return index;
+}
+
 GtkWidget *
 gnumeric_create_tooltip (void)
 {
@@ -564,14 +669,11 @@ gnumeric_position_tooltip (GtkWidget *tip, int horizontal)
  * eg '=sum', or 'bob' are not while '=sum(' is
  */
 gboolean
-gnumeric_entry_at_subexpr_boundary_p (GtkWidget const * const w)
+gnumeric_entry_at_subexpr_boundary_p (GtkEntry *entry)
 {
-	GtkEntry *entry;
 	int cursor_pos;
 
-	g_return_val_if_fail (w, FALSE);
-	entry = GTK_ENTRY (w);
-	g_return_val_if_fail (entry, FALSE);
+	g_return_val_if_fail (entry != NULL, FALSE);
 
 	cursor_pos = GTK_EDITABLE (entry)->current_pos;
 
