@@ -11,6 +11,11 @@
 #include "application.h"
 #include "history.h"
 #include "workbook.h"
+#include "workbook-private.h"
+
+#ifdef ENABLE_BONOBO
+#include <bonobo.h>
+#endif
 
 /* Command callback called on activation of a file history menu item. */
 #ifndef ENABLE_BONOBO
@@ -64,8 +69,15 @@ static gchar*
 history_item_label (const gchar *name, const gint accel_number)
 {
 	int   i;
-	char *label = g_strdup_printf ("_%d %s", accel_number,
-					  g_basename (name));
+	char *label, *menuname, *tmp;
+
+	/* Translate '_' to '-' so menu will not show underline.  */
+	menuname = g_strdup (g_basename (name));
+	for (tmp = menuname; *tmp; tmp++)
+		if (*tmp == '_')
+			*tmp = '-';
+	label = g_strdup_printf ("_%d %s", accel_number, menuname);
+	g_free (menuname);
 
 	for (i = strlen (label) - 1; i >= 0; i--)
 		if (label [i] == '.') {
@@ -102,10 +114,10 @@ history_menu_item_create (Workbook *wb, gchar *name, gint accel_number,
 		gchar *path;
 
 		path = g_strconcat (_("/File/"), info[0].label, NULL);
-		bonobo_ui_handler_menu_new_item (wb->uih, path, info[0].label, name, 
+		bonobo_ui_handler_menu_new_item (wb->priv->uih, path, info[0].label, name, 
 						pos, BONOBO_UI_HANDLER_PIXMAP_NONE, 
 						NULL, 0, GDK_SHIFT_MASK, 
-						(BonoboUIHandlerCallbackFunc)file_history_cmd, 
+						(BonoboUIHandlerCallback)file_history_cmd, 
 						wb);
 		g_free (path);
 	}
@@ -132,11 +144,12 @@ history_menu_locate_separator (Workbook *wb)
 	MenuPos ret;
 	
 #ifndef ENABLE_BONOBO
+	char const * menu_name = _("File/Print preview");
 	ret.menu = gnome_app_find_menu_pos (GNOME_APP (wb->toplevel)->menubar, 
-					    _("File/Print preview"), &ret.pos);
+					    menu_name, &ret.pos);
 #else
 	ret.menu = NULL;
-	ret.pos = bonobo_ui_handler_menu_get_pos (wb->uih,
+	ret.pos = bonobo_ui_handler_menu_get_pos (wb->priv->uih,
 						   "/File/Print preview");
 	ret.pos++; /* see NOTE above */
 #endif
@@ -153,15 +166,21 @@ history_menu_insert_separator (Workbook *wb)
 	
 #ifndef ENABLE_BONOBO
 	GtkWidget *item;
+	char const * menu_name = _("File/Print preview");
 
 	ret.menu = gnome_app_find_menu_pos (GNOME_APP (wb->toplevel)->menubar, 
-					    _("File/Print preview"), &ret.pos);
-	item = gtk_menu_item_new ();
-	gtk_widget_show (item);
-	gtk_menu_shell_insert (GTK_MENU_SHELL (ret.menu), item, ret.pos);
+					    menu_name, &ret.pos);
+	if (ret.menu != NULL) {
+		item = gtk_menu_item_new ();
+		gtk_widget_show (item);
+		gtk_menu_shell_insert (GTK_MENU_SHELL (ret.menu), item, ret.pos);
+	} else
+		g_warning ("Probable mis-translation. '%s' : was not found. "
+			   "Does this match the 'File/Print preview' menu exactly ?",
+			   menu_name);
 #else
 	ret = history_menu_locate_separator (wb);
-	bonobo_ui_handler_menu_new_separator (wb->uih, "/File/histsep",
+	bonobo_ui_handler_menu_new_separator (wb->priv->uih, "/File/histsep",
 					      ret.pos);
 #endif
 	return ret;
@@ -211,7 +230,7 @@ history_menu_remove_items (Workbook *wb, GList *name_list)
 	for (l = name_list; l; l = l->next) {
 		label = history_item_label ((gchar *)l->data, accel_number++);
 		path = g_strconcat ("/File/", label, NULL);
-		bonobo_ui_handler_menu_remove (wb->uih, path);
+		bonobo_ui_handler_menu_remove (wb->priv->uih, path);
 		g_free (label);
 		g_free (path);
 	}
