@@ -29,8 +29,8 @@
 #include "clipboard.h"
 
 /* Some nice warning messages */
-#define WARN_TOO_MANY_ROWS "Too many rows in data to parse : %d"
-#define WARN_TOO_MANY_COLS "Too many columns in data to parse : %d"
+#define WARN_TOO_MANY_ROWS _("Too many rows in data to parse: %d")
+#define WARN_TOO_MANY_COLS _("Too many columns in data to parse: %d")
 
 /* CacheItem_t struct, used for the caching engine */
 typedef struct {
@@ -64,16 +64,17 @@ stf_parse_options_new (void)
 {
 	StfParseOptions_t* parseoptions = g_new0 (StfParseOptions_t, 1);
 
-	parseoptions->parsetype  = PARSE_TYPE_NOTSET;
-	parseoptions->terminator = '\n';
-	parseoptions->parselines = -1;
+	parseoptions->parsetype   = PARSE_TYPE_NOTSET;
+	parseoptions->terminator  = '\n';
+	parseoptions->parselines  = -1;
+	parseoptions->trim_spaces = (TRIM_TYPE_RIGHT | TRIM_TYPE_LEFT);
 
-	parseoptions->splitpositions = g_array_new (FALSE, FALSE, sizeof (int));
+	parseoptions->splitpositions    = g_array_new (FALSE, FALSE, sizeof (int));
 	parseoptions->oldsplitpositions = NULL;
-	parseoptions->modificationmode = FALSE;
+	parseoptions->modificationmode  = FALSE;
 
 	parseoptions->indicator_2x_is_single = TRUE;
-	parseoptions->duplicates = FALSE;
+	parseoptions->duplicates             = FALSE;
 
 	return parseoptions;
 }
@@ -163,6 +164,25 @@ stf_parse_options_set_lines_to_parse (StfParseOptions_t *parseoptions, int lines
 	parseoptions->parselines = lines;
 }
 
+/**
+ * stf_parse_options_set_trim_spaces:
+ * @parseoptions: a parse options struct
+ * @trim_spaces: whether you want to trim spaces or not
+ * 
+ * If enabled will trim spaces in every parsed field on left and right
+ * sides.
+ **/
+void
+stf_parse_options_set_trim_spaces (StfParseOptions_t *parseoptions, StfTrimType_t trim_spaces)
+{
+	g_return_if_fail (parseoptions != NULL);
+
+	if (parseoptions->trim_spaces != trim_spaces)
+		parseoptions->modified = TRUE;
+
+	parseoptions->trim_spaces = trim_spaces;
+}
+
 /**
  * stf_parse_options_before_modification
  * @parseoptions : a parse options struct
@@ -625,6 +645,27 @@ stf_cache_options_valid (StfCacheOptions_t *cacheoptions)
  * STF PARSE : The actual routines that do the 'trick'
  *******************************************************************************************************/
 
+static void
+trim_spaces_inplace (char *field, const StfParseOptions_t *parseoptions)
+{
+	unsigned char *s = (unsigned char *)field;
+
+	if (!s) return;
+
+	if (isspace (*s) && parseoptions->trim_spaces & TRIM_TYPE_LEFT) {
+		unsigned char *tmp = s;
+		while (isspace (*tmp)) tmp++;
+		strcpy (s, tmp);
+	}
+
+	if (parseoptions->trim_spaces & TRIM_TYPE_RIGHT) {
+		int len = strlen (s);
+		while (len && isspace (s[len - 1]))
+			s[--len] = 0;
+	}
+}
+
+
 /**
  * stf_parse_csv_is_separator
  * @character : pointer to the character to check
@@ -780,9 +821,10 @@ stf_parse_csv_line (Source_t *src, StfParseOptions_t *parseoptions)
 	g_return_val_if_fail (parseoptions != NULL, NULL);
 
 	while (*src->position && *src->position != parseoptions->terminator) {
-
 		field = stf_parse_csv_cell (src, parseoptions);
 
+		trim_spaces_inplace (field, parseoptions);
+
 		if (list != NULL) {
 
 			listend = g_slist_append (listend, field)->next;
@@ -813,7 +855,8 @@ stf_parse_fixed_cell (Source_t *src, StfParseOptions_t *parseoptions)
 {
 	GString *res;
 	const char* cur;
-	int splitval, len = 0;
+	int splitval;
+	int len = 0;
 
 	g_return_val_if_fail (src != NULL, NULL);
 	g_return_val_if_fail (parseoptions != NULL, NULL);
@@ -864,7 +907,6 @@ stf_parse_fixed_line (Source_t *src, StfParseOptions_t *parseoptions)
 {
 	GSList *list = NULL;
 	GSList *listend = NULL;
-	char *field;
 	int col = 0;
 
 	g_return_val_if_fail (src != NULL, NULL);
@@ -874,14 +916,14 @@ stf_parse_fixed_line (Source_t *src, StfParseOptions_t *parseoptions)
 	src->splitpos = 0;
 
 	while (*src->position && *src->position != parseoptions->terminator) {
+		char *field;
+		field = (char *)stf_parse_fixed_cell (src, parseoptions);
+
+		trim_spaces_inplace (field, parseoptions);
 
-		field = stf_parse_fixed_cell (src, parseoptions);
-		
 		if (list != NULL) {
-
 			listend = g_slist_append (listend, field)->next;
 		} else {
-
 			list = g_slist_append (list, field);
 			listend = list;
 		}
@@ -1173,11 +1215,11 @@ stf_parse_get_longest_row_width (StfParseOptions_t *parseoptions, const char *da
 				longest = len;
 
 			len = 0;
+			row++;
 		}
 
 		iterator++;
 		len++;
-		row++;
 
 		if (parseoptions->parselines != -1)
 			if (row > parseoptions->parselines)
